#!/bin/sh -u

#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: pf.sh,v $
#	$Revision: 1.5 $
#	$Date: 2006/12/28 16:38:12 $
#	$Author: zapreevis $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	Source description: Compare two files in an IF statement, checking the return status of DIFF.
#		We are interested in is the exit status of DIFF.
#

echo -n "..........????"

#Test whether there is the required golden file present in the archive
GOLDEN_FILES_ZIP=`ls * | grep ${TEST_NAME}.zip`
if test ! -z "${GOLDEN_FILES_ZIP}"; then
	GOLDEN_FILE_IN_ZIP=`eval unzip -l ${TEST_NAME}.zip | grep $1.golden`
	if test ! -z "${GOLDEN_FILE_IN_ZIP}"; then
		#Unpack the golden files
		unzip -u ${TEST_NAME}.zip $1.golden 2>&1 1>/dev/null
	fi
fi

if test -f $1.golden ; then
	#Preprocess the golden file
	cat $1.golden | sed -f ${LUMPING_SED_SCRIPTS}/sed.rules > $1.golden.tmp
else
	#Just create a dummy 
	echo "ERROR: THE REQUIRED GOLDEN FILE $1.golden WAS NOT FOUND" > $1.golden.tmp
fi
#Preprocess the out file
cat $1.out | sed -f ${LUMPING_SED_SCRIPTS}/sed.rules > $1.out.tmp

#Percorm the check
if diff $1.golden.tmp $1.out.tmp > $1.diff ; then
	echo -e "\b\b\b\bPASS"
	rm $1.out $1.diff
else
	echo -e "\b\b\b\bFAIL"
fi

#Remove temp files
rm -f $1.golden $1.golden.tmp $1.out.tmp
